// ************************************************************
//   This class is part of the Sizmek HTML5 Weather Ad Feature 
//   ALL RIGHTS RESERVED TO © 2017 Sizmek, Inc.
// ************************************************************
// ************************************************************

var AerisWeather = function (config) {
    // Save Reference to Script Name 
	this.scriptName		= "Weather";
	// Script Version
	var scriptVersion	= "3.0.0";
	// Last Modified
	var lastModified	= "2017-1-30";
	// Last Modified
	var lastUploaded	= "2017-1-30";
	// Block Id
	this.blockId		= 6119;
    // Establish Config Object
    this.config = config;
    // Establish Boolean for tracking
    this.trackOnce = true;
    // Establish Var for API Timeout
    this.AerisTimeout;
    // Establish Reference to this
    var self = this;
    
    // Create Script Tag to load display file
    var scriptTag = document.createElement('script');
    // Create Script Tag ID
    scriptTag.setAttribute('id', 'WeatherDisplay');
    // Create Script Tag Type
    scriptTag.type = "text/javascript";
    // Build Script Tag Src
    scriptTag.src = 'scripts/weatherDisplay.js';
    // Place Script Tag in Head
    document.getElementsByTagName('head')[0].appendChild(scriptTag);
    // Call Init Method once AdKit is loaded    
    adkit.onReady(function() { self.init(); });
};

AerisWeather.prototype = {
    // Function That Creates Element Var
    d: function (id) { return document.getElementById(id); },
    // Function That Creates Unique ID
    genUid: function () { return Math.ceil((new Date()).valueOf() * Math.random()).toString().substr(0, 7); },
    // Function to Grab Options From Config
    fetchOptions: function () {
        // Loop through Available Options
        for (var prop in this.availableOptions) {
	        // Verify Property Exists
	        if(!this.availableOptions.hasOwnProperty(prop)) continue; 
	        // Check Config has same property
	        if (this.config.hasOwnProperty('options')) {
	            // If True, Update Options from Config File
	            if (this.config.options.hasOwnProperty(prop)) {
	            	// Update Property Value from config object
	                this.availableOptions[prop] = this.config.options[prop];
	            }
	        }
	    }
    },
    
    // Initialize Weather Ad Feature
    init: function () {
    	// Check ID and Secret and alert if not included
        if (this.config.wthr_id === '' || this.config.wthr_scrt === '' ) {
            alert('You must have a unique Aeris Weather Account and enter your Consumer ID and Consumer Secret');
            return;
        }
                
        // Establish Default Options Array
        this.availableOptions = {
        		width: 300,
	        	height: 250,
	        	wthr_loc_auto: true,
	        	wthr_override_city: "New York",
	        	wthr_override_state: "New York",
	        	wthr_switch: 0,
	        	wthr_temp_cf: "F",
	        	wthr_temp_threshold: 99,
	        	wthr_cond: ['R', 'T', 'S'],
	        	userInit: false 
	    };

        // Check Config File for Options
        this.fetchOptions();
        // Determine whether site is using Secure Protocol
	    var proto = ('https:' == document.location.protocol ? 'https://' : 'http://');
        // Establish API Location
        this.wthr_svr = proto + 'api.aerisapi.com/observations/';
        
        // Determine if using Location Override and Build API String
        if (this.availableOptions.userInit){
        	// Leave as is
        	this.wthr_svr = this.wthr_svr;
        } else if (this.availableOptions.wthr_loc_auto) {
        	// Build API String for location auto detect 
            this.wthr_svr += ':auto?client_id=' + this.config.wthr_id + '&client_secret=' + this.config.wthr_scrt + '&callback=' + this.config.wthr_instance + '.wthr_callback';
        } else {
        	// Build API String using Override City, State
            this.wthr_svr += this.availableOptions.wthr_override_city + ',' + this.availableOptions.wthr_override_state + '?client_id=' + this.config.wthr_id + '&client_secret=' + this.config.wthr_scrt + '&callback=' + this.config.wthr_instance + '.wthr_callback';
        }
        
        // Load Weather API        
    	if (this.availableOptions.userInit){
        	try { displayWeatherInit(this.config, this.availableOptions) } catch (err) {}
    	} else {
    		this.loadWeatherAPI(); 
    	}        
    },
    
    submitZip: function () {
        // Check Text Field for Zip Code
        if (document.getElementById('weather_zip').value) {
            // If Zip exists, Load Weather
            this.loadWeatherAPI();
        }
    },

    // Function to Handle Loading Weather Data
    loadWeatherAPI: function () {
    	// Establish Scope
        var self = this;        
    	// Set Var to Stop Double Callback
        this.callback = true;
        // Set Var to True
        this.proceeded = true;
        // Create Script Tag
        this.scriptTag = document.createElement('script');
        // Create Script Tag ID
        this.scriptTag.setAttribute('id', 'WeatherAPI_' + this.genUid());
        // Create Script Tag Type
        this.scriptTag.type = "text/javascript";        
        // Check for User Init and update API 
        if (this.availableOptions.userInit){
        	// Build Script Tag Src
			this.scriptTag.src = this.wthr_svr + document.getElementById('weather_zip').value + '?client_id=' + this.config.wthr_id + '&client_secret=' + this.config.wthr_scrt + '&callback=' + this.config.wthr_instance + '.wthr_callback';
        } else {
	    	// Build Script Tag Src
			this.scriptTag.src = this.wthr_svr;    
        }        
        // Place Script Tag in Head
        document.getElementsByTagName('head')[0].appendChild(this.scriptTag);
        // Set Timeout in the event that API fails to return object in callback method
        this.AerisTimeout = setTimeout(function () { try { displayWeatherError('Please check your credentials and try again', self.config, self.availableOptions); } catch (err) {} }, 4000);
        
        // DO NOT REMOVE THE FOLLOWING
        // Handle Feature Tracking
		this.trackAdFeatures('data_impression', 'AF_' + this.scriptName + '_' + this.blockId);
    },

    // Reload Weather
    refresh: function () {
        this.status = 0;
        this.loadWeatherAPI();
    },

    // Callback Function for JSONP Request 
    wthr_callback: function (_obj) {
    	// Clear Error handling Timeout
    	clearTimeout(this.AerisTimeout);
        // Only Run Callback Function Once
        if (this.callback) {
            // Display Weather On Successful Response or show Error Message
            if (_obj.success === true) { 
                // Check which condition to switch on 
                if (this.availableOptions.wthr_switch === 1) {
                    // Handle Temp Switch
                    try { do_temp_display(_obj, this.config, this.availableOptions); } catch (err) {}
                } else if (this.availableOptions.wthr_switch === 2) {
                    // Handle Condition Switch
                    try { do_cond_display(_obj, this.config, this.availableOptions); } catch (err) {}
                } else {
	                // Display Weather
	               try { displayWeather(_obj, this.config, this.availableOptions); } catch (err) {}
	            }            
			} else {
            	// Show Error Message
            	try { displayWeatherError(_obj.error.description, this.config, this.availableOptions); } catch (err) {}
            }
            // Reset Callback Boolean
            this.callback = false;
        }
    },
    
    // DO NOT REMOVE THE FOLLOWING 
    // Track Ad Features - accepts interaction name and impression type
    trackAdFeatures: function(_interaction, _noun) { 
    	// Establish var to track local mode
    	var isServed;
    	// Verify ad is not local
    	try { isServed = EB._isServingMode(); } catch (err) {}
    	
		if (isServed && this.trackOnce) { 
			try {
				// Update Boolean
				this.trackOnce = false;	
				// Grab Ad ID
				var adId = EB._adConfig.adId;
				// Grab Session ID
				var sId = EB._adConfig.sID; 
				// Build Tracking Pixel
				var trackingPixel = "https://bs.serving-sys.com/BurstingPipe/adServer.bs?cn=tf&c=19&mc=imp&pli=16479316&PluID=0&ord=%time%&rtu=-1&pcp=$$sID=" + sId + "|adID=" + adId + "|interactionName=" + _interaction + "|noun=" + _noun + "$$"; 
				// Fire Tracking Pixel by creating a new image.
				new Image().src = trackingPixel; 
				
			}  catch (err) {}
		}
    }

};